Index: gpu/PRESUBMIT.py |
diff --git a/skia/PRESUBMIT.py b/gpu/PRESUBMIT.py |
similarity index 63% |
copy from skia/PRESUBMIT.py |
copy to gpu/PRESUBMIT.py |
index 6ba31dc1d94e84fa52bb80cc706486df62867d1a..53fc15355050072dc52f6384327bded3d8032522 100644 |
--- a/skia/PRESUBMIT.py |
+++ b/gpu/PRESUBMIT.py |
@@ -1,8 +1,8 @@ |
-# Copyright 2013 The Chromium Authors. All rights reserved. |
+# Copyright (c) 2014 The Chromium Authors. All rights reserved. |
# Use of this source code is governed by a BSD-style license that can be |
# found in the LICENSE file. |
"""Top-level presubmit script for skia/ |
See http://dev.chromium.org/developers/how-tos/depottools/presubmit-scripts |
for more details about the presubmit API built into depot_tools. |
@@ -10,7 +10,7 @@ for more details about the presubmit API built into depot_tools. |
def GetPreferredTryMasters(project, change): |
return { |
- 'tryserver.blink': { |
- 'linux_blink_rel': set(['defaulttests']), |
- }, |
+ 'tryserver.chromium.gpu': { |
+ 'win_gpu': set(['defaulttests']), |
+ } |
} |
@@ -1,8 +1,8 @@ |
# Use of this source code is governed by a BSD-style license that can be |
# found in the LICENSE file. |
-"""Top-level presubmit script for skia/ |
+"""Top-level presubmit script for gpu/. |
See http://dev.chromium.org/developers/how-tos/depottools/presubmit-scripts |
for more details about the presubmit API built into depot_tools. |